# parsetta
Collection of data parsers and utilities functions

## Installation

Install from [PyPI](https://pypi.org/project/parsetta/)
    <pre><code class="console"> pip install parsetta </code></pre>
